==> ejc-gdjgtask-api-3.0.0-20211028.122132-39-sources.jar: com/ejinac/business/vo/WorkVO.java <==
package com.ejinac.business.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工作
 * 
 * @author generator
 * 
 */
public class WorkVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 任务编码
    private String workTitle; // 工作标题
    private String taskTitle;
    private Long responsibleUserId; // 责任人id
    private String responsibleUserName; // 责任人名称
    private Long responsibleDepId; // 责任部门id
    private String responsibleDepName; // 责任部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date askCompleteDate; // 要求完成时间
    private String feedbackCycle; // 反馈周期
    private String contentDescribe; // 工作内容描述
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date feedbackDate; // 反馈日期
    private Integer taskLevel; // 任务层级
    private String memo; // 备注
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer taskStatus; // 任务状态 0--为开始，1--进行中,2--已完成,3--已关闭
    private Integer whetherOverdue; // 0--否--1---是
    private Integer workStatus; //1--已指派，2--已处理，3--已评论，4--已关闭，5--已完成
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date closeDate; // 关闭时间
    private Long pid; //
    private String assingUserNames;
    private String assingDeptNames;//责任人部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date initiateTime; // 发起时间
    private java.lang.Long promoterId; // 发起人
    private List<WorkHistoryVO> workHistoryVOList = new ArrayList<>();
    private String whetherOverdueName;
    private String feedbackContent;


    /**
     * 任务编码
     */
    public String getCode() {
        return code;
    }

    /**
     * 任务编码
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 工作标题
     */
    public String getWorkTitle() {
        return workTitle;
    }

    /**
     * 工作标题
     */
    public void setWorkTitle(String workTitle) {
        this.workTitle = workTitle;
    }
    /**
     * 责任人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public Long getResponsibleUserId() {
        return responsibleUserId;
    }

    /**
     * 责任人id
     */
    @ReferDeserialTransfer
    public void setResponsibleUserId(Long responsibleUserId) {
        this.responsibleUserId = responsibleUserId;
    }
    /**
     * 责任人名称
     */
    public String getResponsibleUserName() {
        return responsibleUserName;
    }

    /**
     * 责任人名称
     */
    public void setResponsibleUserName(String responsibleUserName) {
        this.responsibleUserName = responsibleUserName;
    }
    /**
     * 责任部门id
     */

    @ReferSerialTransfer(referCode="idm-dept")
    public Long getResponsibleDepId() {
        return responsibleDepId;
    }

    /**
     * 责任部门id
     */
    @ReferDeserialTransfer
    public void setResponsibleDepId(Long responsibleDepId) {
        this.responsibleDepId = responsibleDepId;
    }
    /**
     * 责任部门名称
     */
    public String getResponsibleDepName() {
        return responsibleDepName;
    }

    /**
     * 责任部门名称
     */
    public void setResponsibleDepName(String responsibleDepName) {
        this.responsibleDepName = responsibleDepName;
    }
    /**
     * 要求完成时间
     */
    public java.util.Date getAskCompleteDate() {
        return askCompleteDate;
    }

    /**
     * 要求完成时间
     */
    public void setAskCompleteDate(java.util.Date askCompleteDate) {
        this.askCompleteDate = askCompleteDate;
    }
    /**
     * 反馈周期
     */
    public String getFeedbackCycle() {
        return feedbackCycle;
    }

    /**
     * 反馈周期
     */
    public void setFeedbackCycle(String feedbackCycle) {
        this.feedbackCycle = feedbackCycle;
    }
    /**
     * 工作内容描述
     */
    public String getContentDescribe() {
        return contentDescribe;
    }

    /**
     * 工作内容描述
     */
    public void setContentDescribe(String contentDescribe) {
        this.contentDescribe = contentDescribe;
    }
    /**
     * 反馈日期
     */
    public java.util.Date getFeedbackDate() {
        return feedbackDate;
    }

    /**
     * 反馈日期
     */
    public void setFeedbackDate(java.util.Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    /**
     * 任务层级
     */
    public Integer getTaskLevel() {
        return taskLevel;
    }

    /**
     * 任务层级
     */
    public void setTaskLevel(Integer taskLevel) {
        this.taskLevel = taskLevel;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 处理状态 1--进行中,2--未开始
     */
    public Integer getTaskStatus() {
        return taskStatus;
    }

    /**
     * 处理状态 1--进行中,2--未开始
     */
    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }
    /**
     * 0--否--1---是
     */
    public Integer getWhetherOverdue() {
        return whetherOverdue;
    }

    /**
     * 0--否--1---是
     */
    public void setWhetherOverdue(Integer whetherOverdue) {
        this.whetherOverdue = whetherOverdue;
    }
    /**
     * 0--默认没动作,1--指派,2--处理,3--评论--4--关闭
     */
    public Integer getWorkStatus() {
        return workStatus;
    }

    /**
     * 0--默认没动作,1--指派,2--处理,3--评论--4--关闭
     */
    public void setWorkStatus(Integer workStatus) {
        this.workStatus = workStatus;
    }

    /**
     * 关闭时间
     */
    public java.util.Date getCloseDate() {
        return closeDate;
    }

    /**
     * 关闭时间
     */
    public void setCloseDate(java.util.Date closeDate) {
        this.closeDate = closeDate;
    }

    /**
     * 
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getAssingUserNames() {
        return assingUserNames;
    }

    public void setAssingUserNames(String assingUserNames) {
        this.assingUserNames = assingUserNames;
    }

    public List<WorkHistoryVO> getWorkHistoryVOList() {
        return workHistoryVOList;
    }

    public void setWorkHistoryVOList(List<WorkHistoryVO> workHistoryVOList) {
        this.workHistoryVOList = workHistoryVOList;
    }

    public String getAssingDeptNames() {
        return assingDeptNames;
    }

    public void setAssingDeptNames(String assingDeptNames) {
        this.assingDeptNames = assingDeptNames;
    }

    public String getTaskTitle() {
        return taskTitle;
    }

    public void setTaskTitle(String taskTitle) {
        this.taskTitle = taskTitle;
    }

    public Date getInitiateTime() {
        return initiateTime;
    }

    public void setInitiateTime(Date initiateTime) {
        this.initiateTime = initiateTime;
    }

    public Long getPromoterId() {
        return promoterId;
    }

    public void setPromoterId(Long promoterId) {
        this.promoterId = promoterId;

    }

    public String getWhetherOverdueName() {
        return whetherOverdueName;
    }

    public void setWhetherOverdueName(String whetherOverdueName) {
        this.whetherOverdueName = whetherOverdueName;
    }

    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }
}

==> ejc-gdjgtask-api-3.0.0-20211124.023250-48-sources.jar: com/ejinac/business/vo/WorkVO.java <==
package com.ejinac.business.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工作
 * 
 * @author generator
 * 
 */
public class WorkVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 任务编码
    private String workTitle; // 工作标题
    private String taskTitle;
    private Long responsibleUserId; // 责任人id
    private String responsibleUserName; // 责任人名称
    private Long responsibleDepId; // 责任部门id
    private String responsibleDepName; // 责任部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date askCompleteDate; // 要求完成时间
    private String feedbackCycle; // 反馈周期
    private String contentDescribe; // 工作内容描述
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date feedbackDate; // 反馈日期
    private Integer taskLevel; // 任务层级
    private String memo; // 备注
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer taskStatus; // 任务状态 0--为开始，1--进行中,2--已完成,3--已关闭
    private Integer whetherOverdue; // 0--否--1---是
    private Integer workStatus; //1--已指派，2--已处理，3--已评论，4--已关闭，5--已完成
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date closeDate; // 关闭时间
    private Long pid; //
    private String assingUserNames;
    private String assingDeptNames;//责任人部门名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date initiateTime; // 发起时间
    private java.lang.Long promoterId; // 发起人
    private List<WorkHistoryVO> workHistoryVOList = new ArrayList<>();
    private String whetherOverdueName;
    private String feedbackContent;
    private Boolean whetherWarn;

    /**
     * 任务编码
     */
    public String getCode() {
        return code;
    }

    /**
     * 任务编码
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 工作标题
     */
    public String getWorkTitle() {
        return workTitle;
    }

    /**
     * 工作标题
     */
    public void setWorkTitle(String workTitle) {
        this.workTitle = workTitle;
    }
    /**
     * 责任人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public Long getResponsibleUserId() {
        return responsibleUserId;
    }

    /**
     * 责任人id
     */
    @ReferDeserialTransfer
    public void setResponsibleUserId(Long responsibleUserId) {
        this.responsibleUserId = responsibleUserId;
    }
    /**
     * 责任人名称
     */
    public String getResponsibleUserName() {
        return responsibleUserName;
    }

    /**
     * 责任人名称
     */
    public void setResponsibleUserName(String responsibleUserName) {
        this.responsibleUserName = responsibleUserName;
    }
    /**
     * 责任部门id
     */

    @ReferSerialTransfer(referCode="idm-dept")
    public Long getResponsibleDepId() {
        return responsibleDepId;
    }

    /**
     * 责任部门id
     */
    @ReferDeserialTransfer
    public void setResponsibleDepId(Long responsibleDepId) {
        this.responsibleDepId = responsibleDepId;
    }
    /**
     * 责任部门名称
     */
    public String getResponsibleDepName() {
        return responsibleDepName;
    }

    /**
     * 责任部门名称
     */
    public void setResponsibleDepName(String responsibleDepName) {
        this.responsibleDepName = responsibleDepName;
    }
    /**
     * 要求完成时间
     */
    public java.util.Date getAskCompleteDate() {
        return askCompleteDate;
    }

    /**
     * 要求完成时间
     */
    public void setAskCompleteDate(java.util.Date askCompleteDate) {
        this.askCompleteDate = askCompleteDate;
    }
    /**
     * 反馈周期
     */
    public String getFeedbackCycle() {
        return feedbackCycle;
    }

    /**
     * 反馈周期
     */
    public void setFeedbackCycle(String feedbackCycle) {
        this.feedbackCycle = feedbackCycle;
    }
    /**
     * 工作内容描述
     */
    public String getContentDescribe() {
        return contentDescribe;
    }

    /**
     * 工作内容描述
     */
    public void setContentDescribe(String contentDescribe) {
        this.contentDescribe = contentDescribe;
    }
    /**
     * 反馈日期
     */
    public java.util.Date getFeedbackDate() {
        return feedbackDate;
    }

    /**
     * 反馈日期
     */
    public void setFeedbackDate(java.util.Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    /**
     * 任务层级
     */
    public Integer getTaskLevel() {
        return taskLevel;
    }

    /**
     * 任务层级
     */
    public void setTaskLevel(Integer taskLevel) {
        this.taskLevel = taskLevel;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 处理状态 1--进行中,2--未开始
     */
    public Integer getTaskStatus() {
        return taskStatus;
    }

    /**
     * 处理状态 1--进行中,2--未开始
     */
    public void setTaskStatus(Integer taskStatus) {
        this.taskStatus = taskStatus;
    }
    /**
     * 0--否--1---是
     */
    public Integer getWhetherOverdue() {
        return whetherOverdue;
    }

    /**
     * 0--否--1---是
     */
    public void setWhetherOverdue(Integer whetherOverdue) {
        this.whetherOverdue = whetherOverdue;
    }
    /**
     * 0--默认没动作,1--指派,2--处理,3--评论--4--关闭
     */
    public Integer getWorkStatus() {
        return workStatus;
    }

    /**
     * 0--默认没动作,1--指派,2--处理,3--评论--4--关闭
     */
    public void setWorkStatus(Integer workStatus) {
        this.workStatus = workStatus;
    }

    /**
     * 关闭时间
     */
    public java.util.Date getCloseDate() {
        return closeDate;
    }

    /**
     * 关闭时间
     */
    public void setCloseDate(java.util.Date closeDate) {
        this.closeDate = closeDate;
    }

    /**
     * 
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getAssingUserNames() {
        return assingUserNames;
    }

    public void setAssingUserNames(String assingUserNames) {
        this.assingUserNames = assingUserNames;
    }

    public List<WorkHistoryVO> getWorkHistoryVOList() {
        return workHistoryVOList;
    }

    public void setWorkHistoryVOList(List<WorkHistoryVO> workHistoryVOList) {
        this.workHistoryVOList = workHistoryVOList;
    }

    public String getAssingDeptNames() {
        return assingDeptNames;
    }

    public void setAssingDeptNames(String assingDeptNames) {
        this.assingDeptNames = assingDeptNames;
    }

    public String getTaskTitle() {
        return taskTitle;
    }

    public void setTaskTitle(String taskTitle) {
        this.taskTitle = taskTitle;
    }

    public Date getInitiateTime() {
        return initiateTime;
    }

    public void setInitiateTime(Date initiateTime) {
        this.initiateTime = initiateTime;
    }

    public Long getPromoterId() {
        return promoterId;
    }

    public void setPromoterId(Long promoterId) {
        this.promoterId = promoterId;

    }

    public String getWhetherOverdueName() {
        return whetherOverdueName;
    }

    public void setWhetherOverdueName(String whetherOverdueName) {
        this.whetherOverdueName = whetherOverdueName;
    }

    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }

    public Boolean getWhetherWarn() {
        return whetherWarn;
    }

    public void setWhetherWarn(Boolean whetherWarn) {
        this.whetherWarn = whetherWarn;
    }
}
